@@ -296,7 +296,7 @@ int array_print(array *a, int depth) {
 			int j;
 
 			if (i && (i % 5) == 0) {
-				fprintf(stderr, "# %d\n", i);
+				fprintf(stderr, "# %zd\n", i);
 				array_print_indent(depth + 1);
 			}
 			fprintf(stderr, "\"%s\"", du->key->ptr);
@@ -310,7 +310,7 @@ int array_print(array *a, int depth) {
 	}
 	if (!(i && (i - 1 % 5) == 0)) {
 		array_print_indent(depth + 1);
-		fprintf(stderr, "# %d\n", i);
+		fprintf(stderr, "# %zd\n", i);
 	}
 	array_print_indent(depth);
 	fprintf(stderr, ")");
