@@ -124,6 +124,9 @@ typedef union {
 	struct sockaddr_in6 ipv6;
 #endif
 	struct sockaddr_in ipv4;
+#ifdef HAVE_SYS_UN_H
+	struct sockaddr_un un;
+#endif
 	struct sockaddr plain;
 } sock_addr;
 
@@ -257,7 +260,7 @@ typedef struct {
 	unsigned short use_ipv6;
 	unsigned short is_ssl;
 	unsigned short allow_http11;
-	unsigned short force_lower_case; /* if the FS is case-insensitive, force all files to lower-case */
+	unsigned short force_lowercase_filenames; /* if the FS is case-insensitive, force all files to lower-case */
 	unsigned short max_request_size;
 
 	unsigned short kbytes_per_second; /* connection kb/s limit */
@@ -286,7 +289,21 @@ typedef struct {
 #endif
 } specific_config;
 
-typedef enum { CON_STATE_CONNECT, CON_STATE_REQUEST_START, CON_STATE_READ, CON_STATE_REQUEST_END, CON_STATE_READ_POST, CON_STATE_HANDLE_REQUEST, CON_STATE_RESPONSE_START, CON_STATE_WRITE, CON_STATE_RESPONSE_END, CON_STATE_ERROR, CON_STATE_CLOSE } connection_state_t;
+/* the order of the items should be the same as they are processed
+ * read before write as we use this later */
+typedef enum { 
+	CON_STATE_CONNECT, 
+	CON_STATE_REQUEST_START, 
+	CON_STATE_READ, 
+	CON_STATE_REQUEST_END, 
+	CON_STATE_READ_POST, 
+	CON_STATE_HANDLE_REQUEST, 
+	CON_STATE_RESPONSE_START, 
+	CON_STATE_WRITE, 
+	CON_STATE_RESPONSE_END, 
+	CON_STATE_ERROR, 
+	CON_STATE_CLOSE 
+} connection_state_t;
 
 typedef enum { COND_RESULT_UNSET, COND_RESULT_FALSE, COND_RESULT_TRUE } cond_result_t;
 typedef struct {
@@ -439,7 +456,9 @@ typedef struct {
 	buffer *event_handler;
 	
 	buffer *modules_dir;
+	buffer *network_backend;
 	array *modules;
+	array *upload_tempdirs;
 	
 	unsigned short max_worker;
 	unsigned short max_fds;
@@ -454,6 +473,7 @@ typedef struct {
 			STAT_CACHE_ENGINE_SIMPLE, 
 			STAT_CACHE_ENGINE_FAM 
 	} stat_cache_engine;
+	unsigned short enable_cores;
 } server_config;
 
 typedef struct {
@@ -480,7 +500,7 @@ typedef struct {
 	size_t used;
 } server_socket_array;
 
-typedef struct {
+typedef struct server {
 	server_socket_array srv_sockets;
 	
 	/* the errorlog */
@@ -506,7 +526,7 @@ typedef struct {
 	int want_fds;   /* waiting fds */
 	int sockets_disabled;
 	
-	int max_conns;
+	size_t max_conns;
 
 	/* buffers */
 	buffer *parse_full_path;
@@ -553,9 +573,31 @@ typedef struct {
 	connections *fdwaitqueue;
 	
 	stat_cache  *stat_cache;
+
+	/**
+	 * The status array can carry all the status information you want
+	 * the key to the array is <module-prefix>.<name>
+	 * and the values are counters
+	 *
+	 * example:
+	 *   fastcgi.backends        = 10
+	 *   fastcgi.active-backends = 6
+	 *   fastcgi.backend.<key>.load = 24
+	 *   fastcgi.backend.<key>....
+	 *
+	 *   fastcgi.backend.<key>.disconnects = ...
+	 */
+	array *status;
 	
 	fdevent_handler_t event_handler;
 
+	int (* network_backend_write)(struct server *srv, connection *con, int fd, chunkqueue *cq);
+	int (* network_backend_read)(struct server *srv, connection *con, int fd, chunkqueue *cq);
+#ifdef USE_OPENSSL
+	int (* network_ssl_backend_write)(struct server *srv, connection *con, SSL *ssl, chunkqueue *cq);
+	int (* network_ssl_backend_read)(struct server *srv, connection *con, SSL *ssl, chunkqueue *cq);
+#endif
+
 	uid_t uid;
 	gid_t gid;
 } server;
