@@ -44,7 +44,7 @@ static int config_insert(server *srv) {
 		{ "server.max-request-size",     NULL, T_CONFIG_SHORT, T_CONFIG_SCOPE_CONNECTION },   /* 12 */
 		{ "server.max-worker",           NULL, T_CONFIG_SHORT, T_CONFIG_SCOPE_SERVER },       /* 13 */
 		{ "server.document-root",        NULL, T_CONFIG_STRING, T_CONFIG_SCOPE_CONNECTION },  /* 14 */
-		{ "server.force-lower-case-files", NULL, T_CONFIG_BOOLEAN, T_CONFIG_SCOPE_SERVER },   /* 15 */
+		{ "server.force-lowercase-filenames", NULL, T_CONFIG_BOOLEAN, T_CONFIG_SCOPE_SERVER },   /* 15 */
 		{ "debug.log-condition-handling", NULL, T_CONFIG_BOOLEAN, T_CONFIG_SCOPE_SERVER },    /* 16 */
 		{ "server.max-keep-alive-requests", NULL, T_CONFIG_SHORT, T_CONFIG_SCOPE_CONNECTION }, /* 17 */
 		{ "server.name",                 NULL, T_CONFIG_STRING, T_CONFIG_SCOPE_CONNECTION },  /* 18 */
@@ -77,6 +77,9 @@ static int config_insert(server *srv) {
 		{ "server.range-requests",       NULL, T_CONFIG_BOOLEAN, T_CONFIG_SCOPE_CONNECTION }, /* 40 */
 		{ "server.stat-cache-engine",    NULL, T_CONFIG_STRING, T_CONFIG_SCOPE_CONNECTION },  /* 41 */
 		{ "server.max-connections",      NULL, T_CONFIG_SHORT, T_CONFIG_SCOPE_SERVER },       /* 42 */
+		{ "server.network-backend",      NULL, T_CONFIG_STRING, T_CONFIG_SCOPE_CONNECTION },  /* 43 */
+		{ "server.upload-dirs",          NULL, T_CONFIG_ARRAY, T_CONFIG_SCOPE_CONNECTION },   /* 44 */
+		{ "server.core-files",           NULL, T_CONFIG_BOOLEAN, T_CONFIG_SCOPE_CONNECTION }, /* 45 */
 		
 		{ "server.host",                 "use server.bind instead", T_CONFIG_DEPRECATED, T_CONFIG_SCOPE_UNSET },
 		{ "server.docroot",              "use server.document-root instead", T_CONFIG_DEPRECATED, T_CONFIG_SCOPE_UNSET },
@@ -86,6 +89,7 @@ static int config_insert(server *srv) {
 		{ "server.userid",               "use server.username instead", T_CONFIG_DEPRECATED, T_CONFIG_SCOPE_UNSET },
 		{ "server.groupid",              "use server.groupname instead", T_CONFIG_DEPRECATED, T_CONFIG_SCOPE_UNSET },
 		{ "server.use-keep-alive",       "use server.max-keep-alive-requests = 0 instead", T_CONFIG_DEPRECATED, T_CONFIG_SCOPE_UNSET },
+		{ "server.force-lower-case-files",       "use server.force-lowercase-filenames instead", T_CONFIG_DEPRECATED, T_CONFIG_SCOPE_UNSET },
 		
 		{ NULL,                          NULL, T_CONFIG_UNSET, T_CONFIG_SCOPE_UNSET }
 	};
@@ -112,6 +116,9 @@ static int config_insert(server *srv) {
 	
 	stat_cache_string = buffer_init();
 	cv[41].destination = stat_cache_string;
+	cv[43].destination = srv->srvconf.network_backend;
+	cv[44].destination = srv->srvconf.upload_tempdirs;
+	cv[45].destination = &(srv->srvconf.enable_cores);
 	
 	cv[42].destination = &(srv->srvconf.max_conns);
 	cv[12].destination = &(srv->srvconf.max_request_size);
@@ -143,7 +150,7 @@ static int config_insert(server *srv) {
 		s->kbytes_per_second = 0;
 		s->allow_http11  = 1;
 		s->range_requests = 1;
-		s->force_lower_case = 0;
+		s->force_lowercase_filenames = 0;
 		s->global_kbytes_per_second = 0;
 		s->global_bytes_per_second_cnt = 0;
 		s->global_bytes_per_second_cnt_ptr = &s->global_bytes_per_second_cnt;
@@ -156,7 +163,7 @@ static int config_insert(server *srv) {
 		
 		/* 13 max-worker */
 		cv[14].destination = s->document_root;
-		cv[15].destination = &(s->force_lower_case);
+		cv[15].destination = &(s->force_lowercase_filenames);
 		cv[16].destination = &(s->log_condition_handling);
 		cv[17].destination = &(s->max_keep_alive_requests);
 		cv[18].destination = s->server_name;
@@ -190,7 +197,7 @@ static int config_insert(server *srv) {
 	}
 	
 	if (buffer_is_empty(stat_cache_string)) {
-		srv->srvconf.stat_cache_engine = STAT_CACHE_ENGINE_NONE;
+		srv->srvconf.stat_cache_engine = STAT_CACHE_ENGINE_SIMPLE;
 	} else if (buffer_is_equal_string(stat_cache_string, CONST_STR_LEN("simple"))) {
 		srv->srvconf.stat_cache_engine = STAT_CACHE_ENGINE_SIMPLE;
 	} else if (buffer_is_equal_string(stat_cache_string, CONST_STR_LEN("fam"))) {
@@ -240,7 +247,7 @@ int config_setup_connection(server *srv, connection *con) {
 	PATCH(log_file_not_found);
 	
 	PATCH(range_requests);
-	PATCH(force_lower_case);
+	PATCH(force_lowercase_filenames);
 	PATCH(is_ssl);
 	
 	PATCH(ssl_pemfile);
@@ -312,8 +319,8 @@ int config_patch_connection(server *srv, connection *con, comp_key_t comp) {
 				PATCH(log_file_not_found);
 			} else if (buffer_is_equal_string(du->key, CONST_STR_LEN("server.protocol-http11"))) {
 				PATCH(allow_http11);
-			} else if (buffer_is_equal_string(du->key, CONST_STR_LEN("server.force-lower-case-files"))) {  
-				PATCH(force_lower_case);
+			} else if (buffer_is_equal_string(du->key, CONST_STR_LEN("server.force-lowercase-filenames"))) {  
+				PATCH(force_lowercase_filenames);
 			} else if (buffer_is_equal_string(du->key, CONST_STR_LEN("server.kbytes-per-second"))) {
 				PATCH(global_kbytes_per_second);
 				PATCH(global_bytes_per_second_cnt);
@@ -442,7 +449,7 @@ static int config_tokenizer(server *srv, tokenizer_t *t, int *token_id, buffer *
 					log_error_write(srv, __FILE__, __LINE__, "sbsdsds", 
 							"source:", t->source,
 							"line:", t->line, "pos:", t->line_pos, 
-							"only =~ and == are allow in the condition");
+							"only =~ and == are allowed in the condition");
 					return -1;
 				}
 				t->in_key = 1;
@@ -481,7 +488,7 @@ static int config_tokenizer(server *srv, tokenizer_t *t, int *token_id, buffer *
 					log_error_write(srv, __FILE__, __LINE__, "sbsdsds", 
 							"source:", t->source,
 							"line:", t->line, "pos:", t->line_pos, 
-							"only !~ and != are allow in the condition");
+							"only !~ and != are allowed in the condition");
 					return -1;
 				}
 				t->in_key = 1;
@@ -724,6 +731,8 @@ static int config_tokenizer(server *srv, tokenizer_t *t, int *token_id, buffer *
 						tid = TK_INCLUDE;
 					} else if (strcmp(token->ptr, "include_shell") == 0) {
 						tid = TK_INCLUDE_SHELL;
+					} else if (strcmp(token->ptr, "global") == 0) {
+						tid = TK_GLOBAL;
 					} else if (strcmp(token->ptr, "else") == 0) {
 						tid = TK_ELSE;
 					} else {
@@ -901,6 +910,7 @@ int config_read(server *srv, const char *fn) {
 	config_t context;
 	data_config *dc;
 	data_integer *dpid;
+	data_string *dcwd;
 	int ret;
 	char *pos;
 	data_array *modules;
@@ -935,6 +945,14 @@ int config_read(server *srv, const char *fn) {
 	buffer_copy_string(dpid->key, "var.PID");
 	array_insert_unique(srv->config, (data_unset *)dpid);
 	
+	dcwd = data_string_init();
+	buffer_prepare_copy(dcwd->value, 1024);
+	if (NULL != getcwd(dcwd->value->ptr, dcwd->value->size - 1)) {
+		dcwd->value->used = strlen(dcwd->value->ptr) + 1;
+		buffer_copy_string(dcwd->key, "var.CWD");
+		array_insert_unique(srv->config, (data_unset *)dcwd);
+	}
+
 	ret = config_parse_file(srv, &context, fn);
 
 	/* remains nothing if parser is ok */
@@ -987,6 +1005,26 @@ int config_read(server *srv, const char *fn) {
 			buffer_copy_string(ds->value, "mod_staticfile");
 			array_insert_unique(modules->value, (data_unset *)ds);
 		}
+	} else {
+		data_string *ds;
+
+		modules = data_array_init();
+
+		/* server.modules is not set */
+		ds = data_string_init();
+		buffer_copy_string(ds->value, "mod_indexfile");
+		array_insert_unique(modules->value, (data_unset *)ds);
+
+		ds = data_string_init();
+		buffer_copy_string(ds->value, "mod_dirlisting");
+		array_insert_unique(modules->value, (data_unset *)ds);
+
+		ds = data_string_init();
+		buffer_copy_string(ds->value, "mod_staticfile");
+		array_insert_unique(modules->value, (data_unset *)ds);
+
+		buffer_copy_string(modules->key, "server.modules");
+		array_insert_unique(srv->config, (data_unset *)modules);
 	}
 	
 
@@ -1030,6 +1068,7 @@ int config_set_defaults(server *srv) {
 		{ FDEVENT_HANDLER_UNSET,          NULL }
 	};
 	
+
 	if (buffer_is_empty(s->document_root)) {  
 		log_error_write(srv, __FILE__, __LINE__, "s",  
 				"a default document-root has to be set");  
@@ -1080,7 +1119,7 @@ int config_set_defaults(server *srv) {
 			 * an other filename, no need to stat(), 
 			 * just assume it is case-sensitive. */
 
-			s->force_lower_case = 0;
+			s->force_lowercase_filenames = 0;
 		} else if (0 == stat(srv->tmp_buf->ptr, &st2)) {  
 
 			/* upper case exists too, doesn't the FS handle this ? */  
@@ -1090,7 +1129,7 @@ int config_set_defaults(server *srv) {
 			if (st1.st_ino == st2.st_ino) {  
 				/* upper and lower have the same inode -> case-insensitve FS */  
 				
-				s->force_lower_case = 1;  
+				s->force_lowercase_filenames = 1;  
 			}  
 		}  
 	}  
