@@ -175,27 +175,27 @@ data_unset *configparser_merge_data(data_unset *op1, const data_unset *op2) {
 */
 /*  */
 #define YYCODETYPE unsigned char
-#define YYNOCODE 45
+#define YYNOCODE 48
 #define YYACTIONTYPE unsigned char
 #define configparserTOKENTYPE buffer *
 typedef union {
   configparserTOKENTYPE yy0;
-  buffer * yy1;
-  config_cond_t yy29;
-  data_unset * yy43;
-  data_config * yy74;
-  array * yy78;
-  int yy89;
+  config_cond_t yy27;
+  array * yy40;
+  data_unset * yy41;
+  buffer * yy43;
+  data_config * yy78;
+  int yy95;
 } YYMINORTYPE;
 #define YYSTACKDEPTH 100
 #define configparserARG_SDECL config_t *ctx;
 #define configparserARG_PDECL ,config_t *ctx
 #define configparserARG_FETCH config_t *ctx = yypParser->ctx
 #define configparserARG_STORE yypParser->ctx = ctx
-#define YYNSTATE 56
-#define YYNRULE 36
-#define YYERRORSYMBOL 25
-#define YYERRSYMDT yy89
+#define YYNSTATE 62
+#define YYNRULE 39
+#define YYERRORSYMBOL 26
+#define YYERRSYMDT yy95
 #define YY_NO_ACTION      (YYNSTATE+YYNRULE+2)
 #define YY_ACCEPT_ACTION  (YYNSTATE+YYNRULE+1)
 #define YY_ERROR_ACTION   (YYNSTATE+YYNRULE)
@@ -248,56 +248,61 @@ typedef union {
 **  yy_default[]       Default action for each state.
 */
 static YYACTIONTYPE yy_action[] = {
- /*     0 */     2,    3,    4,   12,   13,   56,   14,    6,   38,   19,
- /*    10 */    79,   15,   27,   26,   35,    9,   28,   24,   21,   32,
- /*    20 */    40,   14,   93,    1,   19,   27,   26,   31,   52,   54,
- /*    30 */    24,   21,   32,    7,   39,   40,   48,   49,   50,   51,
- /*    40 */    27,   43,   18,   52,   54,   24,   21,   44,   27,   43,
- /*    50 */    84,   27,   43,   24,   21,   53,   24,   21,   55,   19,
- /*    60 */    40,   22,   23,   25,   27,   17,   27,   34,   33,   24,
- /*    70 */    21,   24,   21,    5,   27,   37,   10,   27,   47,   24,
- /*    80 */    21,   20,   24,   21,   80,    8,   24,   21,   16,   36,
- /*    90 */    18,   11,    9,   29,   30,   18,   89,   41,   45,   42,
- /*   100 */    46,
+ /*     0 */     2,    3,    4,    5,   13,   14,   62,   15,    7,   44,
+ /*    10 */    20,   86,   16,   45,   28,   48,   40,   10,   39,   25,
+ /*    20 */    22,   49,   45,    8,   15,  102,    1,   20,   28,   18,
+ /*    30 */    57,   59,   19,   25,   22,   39,   19,   61,   98,   45,
+ /*    40 */    20,    6,   23,   24,   26,   28,   35,   57,   59,   12,
+ /*    50 */    25,   22,   28,   27,   36,   87,   29,   25,   22,   33,
+ /*    60 */    15,   30,   31,   20,   28,   38,    9,   17,   37,   25,
+ /*    70 */    22,   39,   42,   43,   10,   45,   11,   53,   54,   55,
+ /*    80 */    56,   28,   52,   57,   59,   34,   25,   22,   28,   27,
+ /*    90 */    32,   88,   41,   25,   22,   33,   28,   48,   46,   28,
+ /*   100 */    48,   25,   22,   58,   25,   22,   60,   21,   19,   47,
+ /*   110 */    51,   50,   25,   22,   88,   88,   93,
 };
 static YYCODETYPE yy_lookahead[] = {
- /*     0 */    28,   29,   30,   31,   32,    0,    1,   42,   36,    4,
- /*    10 */    12,   39,   33,   34,   35,   43,   37,   38,   39,   40,
- /*    20 */    15,    1,   26,   27,    4,   33,   34,   35,   23,   24,
- /*    30 */    38,   39,   40,   12,   14,   15,   19,   20,   21,   22,
- /*    40 */    33,   34,    5,   23,   24,   38,   39,   40,   33,   34,
- /*    50 */    13,   33,   34,   38,   39,   40,   38,   39,   40,    4,
- /*    60 */    15,    6,    7,    8,   33,   34,   33,   34,   11,   38,
- /*    70 */    39,   38,   39,    1,   33,   34,   13,   33,   34,   38,
- /*    80 */    39,   33,   38,   39,   12,   36,   38,   39,    2,    3,
- /*    90 */     5,   27,   43,    9,   10,    5,   11,   16,   18,   17,
- /*   100 */    41,
+ /*     0 */    29,   30,   31,   32,   33,   34,    0,    1,   44,   38,
+ /*    10 */     4,   15,   41,   16,   35,   36,   45,   46,   12,   40,
+ /*    20 */    41,   42,   16,   15,    1,   27,   28,    4,   35,   36,
+ /*    30 */    24,   25,    5,   40,   41,   12,    5,   14,   11,   16,
+ /*    40 */     4,    1,    6,    7,    8,   35,   36,   24,   25,   28,
+ /*    50 */    40,   41,   35,   36,   37,   15,   39,   40,   41,   42,
+ /*    60 */     1,    9,   10,    4,   35,   36,   38,    2,    3,   40,
+ /*    70 */    41,   12,   28,   14,   46,   16,   13,   20,   21,   22,
+ /*    80 */    23,   35,   36,   24,   25,   11,   40,   41,   35,   36,
+ /*    90 */    37,   13,   13,   40,   41,   42,   35,   36,   17,   35,
+ /*   100 */    36,   40,   41,   42,   40,   41,   42,   35,    5,   18,
+ /*   110 */    43,   19,   40,   41,   47,   47,   13,
 };
-#define YY_SHIFT_USE_DFLT (-3)
+#define YY_SHIFT_USE_DFLT (-5)
 static signed char yy_shift_ofst[] = {
- /*     0 */    -3,    5,   -3,   -3,   72,   -2,   21,   45,   -3,   63,
- /*    10 */    -3,   20,   -3,   -3,   -3,   86,   55,   90,   55,   -3,
- /*    20 */    -3,   -3,   -3,   -3,   -3,   55,   85,   -3,   84,   -3,
- /*    30 */    55,   -3,   57,   55,   90,   -3,   55,   90,   -3,   -3,
- /*    40 */    81,   82,   55,   90,   80,   17,   55,   37,   -3,   -3,
- /*    50 */    -3,   -3,   55,   -3,   55,   -3,
+ /*     0 */    -5,    6,   -5,   -5,   -5,   40,   -4,    8,   -3,   -5,
+ /*    10 */    63,   -5,   23,   -5,   -5,   -5,   65,   36,   31,   36,
+ /*    20 */    -5,   -5,   -5,   -5,   -5,   -5,   36,   27,   -5,   52,
+ /*    30 */    -5,   36,   -5,   74,   36,   31,   -5,   36,   31,   78,
+ /*    40 */    79,   -5,   59,   -5,   -5,   81,   91,   36,   31,   92,
+ /*    50 */    57,   36,  103,   -5,   -5,   -5,   -5,   36,   -5,   36,
+ /*    60 */    -5,   -5,
 };
-#define YY_REDUCE_USE_DFLT (-36)
+#define YY_REDUCE_USE_DFLT (-37)
 static signed char yy_reduce_ofst[] = {
- /*     0 */    -4,  -28,  -36,  -36,  -35,  -36,  -36,   49,  -36,  -36,
- /*    10 */    64,  -28,  -36,  -36,  -36,  -36,   31,  -36,   48,  -36,
- /*    20 */   -36,  -36,  -36,  -36,  -36,  -21,  -36,  -36,  -36,  -36,
- /*    30 */    -8,  -36,  -36,   33,  -36,  -36,   41,  -36,  -36,  -36,
- /*    40 */   -36,  -36,    7,  -36,  -36,   59,   44,  -36,  -36,  -36,
- /*    50 */   -36,  -36,   15,  -36,   18,  -36,
+ /*     0 */    -2,  -29,  -37,  -37,  -37,  -36,  -37,  -37,   28,  -37,
+ /*    10 */   -37,   21,  -29,  -37,  -37,  -37,  -37,   -7,  -37,   72,
+ /*    20 */   -37,  -37,  -37,  -37,  -37,  -37,   17,  -37,  -37,  -37,
+ /*    30 */   -37,   53,  -37,  -37,   10,  -37,  -37,   29,  -37,  -37,
+ /*    40 */   -37,   44,  -29,  -37,  -37,  -37,  -37,  -21,  -37,  -37,
+ /*    50 */    67,   46,  -37,  -37,  -37,  -37,  -37,   61,  -37,   64,
+ /*    60 */   -37,  -37,
 };
 static YYACTIONTYPE yy_default[] = {
- /*     0 */    58,   92,   57,   59,   92,   60,   92,   92,   81,   92,
- /*    10 */    58,   92,   61,   62,   63,   92,   92,   64,   92,   66,
- /*    20 */    67,   69,   70,   71,   72,   92,   77,   68,   92,   73,
- /*    30 */    75,   74,   92,   92,   78,   76,   92,   65,   82,   83,
- /*    40 */    92,   92,   92,   89,   92,   92,   92,   92,   85,   86,
- /*    50 */    87,   88,   92,   90,   92,   91,
+ /*     0 */    64,  101,   63,   65,   66,  101,   67,  101,  101,   90,
+ /*    10 */   101,   64,  101,   68,   69,   70,  101,  101,   71,  101,
+ /*    20 */    73,   74,   76,   77,   78,   79,  101,   84,   75,  101,
+ /*    30 */    80,   82,   81,  101,  101,   85,   83,  101,   72,  101,
+ /*    40 */   101,   64,  101,   89,   91,  101,  101,  101,   98,  101,
+ /*    50 */   101,  101,  101,   94,   95,   96,   97,  101,   99,  101,
+ /*    60 */   100,   92,
 };
 #define YY_SZ_ACTTAB (sizeof(yy_action)/sizeof(yy_action[0]))
 
@@ -386,14 +391,15 @@ static const char *yyTokenName[] = {
   "$",             "EOL",           "ASSIGN",        "APPEND",      
   "LKEY",          "PLUS",          "STRING",        "INTEGER",     
   "LPARAN",        "RPARAN",        "COMMA",         "ARRAY_ASSIGN",
-  "ELSE",          "LCURLY",        "RCURLY",        "DOLLAR",      
-  "SRVVARNAME",    "LBRACKET",      "RBRACKET",      "EQ",          
-  "MATCH",         "NE",            "NOMATCH",       "INCLUDE",     
-  "INCLUDE_SHELL",  "error",         "input",         "metalines",   
-  "metaline",      "varline",       "condlines",     "include",     
-  "include_shell",  "value",         "expression",    "aelement",    
-  "condline",      "aelements",     "array",         "key",         
-  "stringop",      "cond",          "eols",          "context",     
+  "GLOBAL",        "LCURLY",        "RCURLY",        "ELSE",        
+  "DOLLAR",        "SRVVARNAME",    "LBRACKET",      "RBRACKET",    
+  "EQ",            "MATCH",         "NE",            "NOMATCH",     
+  "INCLUDE",       "INCLUDE_SHELL",  "error",         "input",       
+  "metalines",     "metaline",      "varline",       "global",      
+  "condlines",     "include",       "include_shell",  "value",       
+  "expression",    "aelement",      "condline",      "aelements",   
+  "array",         "key",           "stringop",      "cond",        
+  "eols",          "globalstart",   "context",     
 };
 #endif /* NDEBUG */
 
@@ -405,38 +411,41 @@ static const char *yyRuleName[] = {
  /*   1 */ "metalines ::= metalines metaline",
  /*   2 */ "metalines ::=",
  /*   3 */ "metaline ::= varline",
- /*   4 */ "metaline ::= condlines EOL",
- /*   5 */ "metaline ::= include",
- /*   6 */ "metaline ::= include_shell",
- /*   7 */ "metaline ::= EOL",
- /*   8 */ "varline ::= key ASSIGN expression",
- /*   9 */ "varline ::= key APPEND expression",
- /*  10 */ "key ::= LKEY",
- /*  11 */ "expression ::= expression PLUS value",
- /*  12 */ "expression ::= value",
- /*  13 */ "value ::= key",
- /*  14 */ "value ::= STRING",
- /*  15 */ "value ::= INTEGER",
- /*  16 */ "value ::= array",
- /*  17 */ "array ::= LPARAN aelements RPARAN",
- /*  18 */ "aelements ::= aelements COMMA aelement",
- /*  19 */ "aelements ::= aelements COMMA",
- /*  20 */ "aelements ::= aelement",
- /*  21 */ "aelement ::= expression",
- /*  22 */ "aelement ::= stringop ARRAY_ASSIGN expression",
- /*  23 */ "eols ::= EOL",
- /*  24 */ "eols ::=",
- /*  25 */ "condlines ::= condlines eols ELSE condline",
- /*  26 */ "condlines ::= condline",
- /*  27 */ "condline ::= context LCURLY metalines RCURLY",
- /*  28 */ "context ::= DOLLAR SRVVARNAME LBRACKET stringop RBRACKET cond expression",
- /*  29 */ "cond ::= EQ",
- /*  30 */ "cond ::= MATCH",
- /*  31 */ "cond ::= NE",
- /*  32 */ "cond ::= NOMATCH",
- /*  33 */ "stringop ::= expression",
- /*  34 */ "include ::= INCLUDE stringop",
- /*  35 */ "include_shell ::= INCLUDE_SHELL stringop",
+ /*   4 */ "metaline ::= global",
+ /*   5 */ "metaline ::= condlines EOL",
+ /*   6 */ "metaline ::= include",
+ /*   7 */ "metaline ::= include_shell",
+ /*   8 */ "metaline ::= EOL",
+ /*   9 */ "varline ::= key ASSIGN expression",
+ /*  10 */ "varline ::= key APPEND expression",
+ /*  11 */ "key ::= LKEY",
+ /*  12 */ "expression ::= expression PLUS value",
+ /*  13 */ "expression ::= value",
+ /*  14 */ "value ::= key",
+ /*  15 */ "value ::= STRING",
+ /*  16 */ "value ::= INTEGER",
+ /*  17 */ "value ::= array",
+ /*  18 */ "array ::= LPARAN aelements RPARAN",
+ /*  19 */ "aelements ::= aelements COMMA aelement",
+ /*  20 */ "aelements ::= aelements COMMA",
+ /*  21 */ "aelements ::= aelement",
+ /*  22 */ "aelement ::= expression",
+ /*  23 */ "aelement ::= stringop ARRAY_ASSIGN expression",
+ /*  24 */ "eols ::= EOL",
+ /*  25 */ "eols ::=",
+ /*  26 */ "globalstart ::= GLOBAL",
+ /*  27 */ "global ::= globalstart LCURLY metalines RCURLY",
+ /*  28 */ "condlines ::= condlines eols ELSE condline",
+ /*  29 */ "condlines ::= condline",
+ /*  30 */ "condline ::= context LCURLY metalines RCURLY",
+ /*  31 */ "context ::= DOLLAR SRVVARNAME LBRACKET stringop RBRACKET cond expression",
+ /*  32 */ "cond ::= EQ",
+ /*  33 */ "cond ::= MATCH",
+ /*  34 */ "cond ::= NE",
+ /*  35 */ "cond ::= NOMATCH",
+ /*  36 */ "stringop ::= expression",
+ /*  37 */ "include ::= INCLUDE stringop",
+ /*  38 */ "include_shell ::= INCLUDE_SHELL stringop",
 };
 #endif /* NDEBUG */
 
@@ -518,45 +527,46 @@ static void yy_destructor(YYCODETYPE yymajor, YYMINORTYPE *yypminor){
     case 22:
     case 23:
     case 24:
-#line 159 "./configparser.y"
+    case 25:
+#line 160 "./configparser.y"
 { buffer_free((yypminor->yy0)); }
-#line 523 "configparser.c"
-      break;
-    case 33:
-#line 150 "./configparser.y"
-{ (yypminor->yy43)->free((yypminor->yy43)); }
-#line 528 "configparser.c"
-      break;
-    case 34:
-#line 151 "./configparser.y"
-{ (yypminor->yy43)->free((yypminor->yy43)); }
 #line 533 "configparser.c"
       break;
     case 35:
-#line 152 "./configparser.y"
-{ (yypminor->yy43)->free((yypminor->yy43)); }
+#line 151 "./configparser.y"
+{ (yypminor->yy41)->free((yypminor->yy41)); }
 #line 538 "configparser.c"
       break;
+    case 36:
+#line 152 "./configparser.y"
+{ (yypminor->yy41)->free((yypminor->yy41)); }
+#line 543 "configparser.c"
+      break;
     case 37:
 #line 153 "./configparser.y"
-{ array_free((yypminor->yy78)); }
-#line 543 "configparser.c"
-      break;
-    case 38:
-#line 154 "./configparser.y"
-{ array_free((yypminor->yy78)); }
+{ (yypminor->yy41)->free((yypminor->yy41)); }
 #line 548 "configparser.c"
       break;
     case 39:
-#line 155 "./configparser.y"
-{ buffer_free((yypminor->yy1)); }
+#line 154 "./configparser.y"
+{ array_free((yypminor->yy40)); }
 #line 553 "configparser.c"
       break;
     case 40:
-#line 156 "./configparser.y"
-{ buffer_free((yypminor->yy1)); }
+#line 155 "./configparser.y"
+{ array_free((yypminor->yy40)); }
 #line 558 "configparser.c"
       break;
+    case 41:
+#line 156 "./configparser.y"
+{ buffer_free((yypminor->yy43)); }
+#line 563 "configparser.c"
+      break;
+    case 42:
+#line 157 "./configparser.y"
+{ buffer_free((yypminor->yy43)); }
+#line 568 "configparser.c"
+      break;
     default:  break;   /* If no destructor action specified: do nothing */
   }
 }
@@ -731,42 +741,45 @@ static struct {
   YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
   unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
 } yyRuleInfo[] = {
-  { 26, 1 },
-  { 27, 2 },
-  { 27, 0 },
-  { 28, 1 },
+  { 27, 1 },
   { 28, 2 },
-  { 28, 1 },
-  { 28, 1 },
-  { 28, 1 },
-  { 29, 3 },
-  { 29, 3 },
-  { 39, 1 },
-  { 34, 3 },
-  { 34, 1 },
-  { 33, 1 },
-  { 33, 1 },
-  { 33, 1 },
-  { 33, 1 },
-  { 38, 3 },
-  { 37, 3 },
-  { 37, 2 },
-  { 37, 1 },
+  { 28, 0 },
+  { 29, 1 },
+  { 29, 1 },
+  { 29, 2 },
+  { 29, 1 },
+  { 29, 1 },
+  { 29, 1 },
+  { 30, 3 },
+  { 30, 3 },
+  { 41, 1 },
+  { 36, 3 },
+  { 36, 1 },
   { 35, 1 },
-  { 35, 3 },
+  { 35, 1 },
+  { 35, 1 },
+  { 35, 1 },
+  { 40, 3 },
+  { 39, 3 },
+  { 39, 2 },
+  { 39, 1 },
+  { 37, 1 },
+  { 37, 3 },
+  { 44, 1 },
+  { 44, 0 },
+  { 45, 1 },
+  { 31, 4 },
+  { 32, 4 },
+  { 32, 1 },
+  { 38, 4 },
+  { 46, 7 },
+  { 43, 1 },
+  { 43, 1 },
+  { 43, 1 },
+  { 43, 1 },
   { 42, 1 },
-  { 42, 0 },
-  { 30, 4 },
-  { 30, 1 },
-  { 36, 4 },
-  { 43, 7 },
-  { 41, 1 },
-  { 41, 1 },
-  { 41, 1 },
-  { 41, 1 },
-  { 40, 1 },
-  { 31, 2 },
-  { 32, 2 },
+  { 33, 2 },
+  { 34, 2 },
 };
 
 static void yy_accept(yyParser*);  /* Forward Declaration */
@@ -816,259 +829,251 @@ static void yy_reduce(
         /* No destructor defined for varline */
         break;
       case 4:
-#line 133 "./configparser.y"
-{ yymsp[-1].minor.yy74 = NULL; }
-#line 821 "configparser.c"
-  yy_destructor(1,&yymsp[0].minor);
+        /* No destructor defined for global */
         break;
       case 5:
-        /* No destructor defined for include */
-        break;
-      case 6:
-        /* No destructor defined for include_shell */
-        break;
-      case 7:
+#line 134 "./configparser.y"
+{ yymsp[-1].minor.yy78 = NULL; }
+#line 837 "configparser.c"
   yy_destructor(1,&yymsp[0].minor);
         break;
+      case 6:
+        /* No destructor defined for include */
+        break;
+      case 7:
+        /* No destructor defined for include_shell */
+        break;
       case 8:
-#line 161 "./configparser.y"
+  yy_destructor(1,&yymsp[0].minor);
+        break;
+      case 9:
+#line 162 "./configparser.y"
 {
-  buffer_copy_string_buffer(yymsp[0].minor.yy43->key, yymsp[-2].minor.yy1);
-  if (NULL == array_get_element(ctx->current->value, yymsp[0].minor.yy43->key->ptr)) {
-    array_insert_unique(ctx->current->value, yymsp[0].minor.yy43);
-    yymsp[0].minor.yy43 = NULL;
+  buffer_copy_string_buffer(yymsp[0].minor.yy41->key, yymsp[-2].minor.yy43);
+  if (NULL == array_get_element(ctx->current->value, yymsp[0].minor.yy41->key->ptr)) {
+    array_insert_unique(ctx->current->value, yymsp[0].minor.yy41);
+    yymsp[0].minor.yy41 = NULL;
   } else {
     fprintf(stderr, "Duplicate config variable in conditional %d %s: %s\n", 
             ctx->current->context_ndx,
-            ctx->current->key->ptr, yymsp[0].minor.yy43->key->ptr);
+            ctx->current->key->ptr, yymsp[0].minor.yy41->key->ptr);
     ctx->ok = 0;
-    yymsp[0].minor.yy43->free(yymsp[0].minor.yy43);
-    yymsp[0].minor.yy43 = NULL;
+    yymsp[0].minor.yy41->free(yymsp[0].minor.yy41);
+    yymsp[0].minor.yy41 = NULL;
   }
-  buffer_free(yymsp[-2].minor.yy1);
-  yymsp[-2].minor.yy1 = NULL;
+  buffer_free(yymsp[-2].minor.yy43);
+  yymsp[-2].minor.yy43 = NULL;
 }
-#line 851 "configparser.c"
+#line 867 "configparser.c"
   yy_destructor(2,&yymsp[-1].minor);
         break;
-      case 9:
-#line 178 "./configparser.y"
+      case 10:
+#line 179 "./configparser.y"
 {
   array *vars = ctx->current->value;
   data_unset *du;
 
-  if (NULL != (du = array_get_element(vars, yymsp[-2].minor.yy1->ptr))) {
+  if (NULL != (du = array_get_element(vars, yymsp[-2].minor.yy43->ptr))) {
     /* exists in current block */
-    du = configparser_merge_data(du, yymsp[0].minor.yy43);
+    du = configparser_merge_data(du, yymsp[0].minor.yy41);
     if (NULL == du) {
       ctx->ok = 0;
     }
     else {
-      buffer_copy_string_buffer(du->key, yymsp[-2].minor.yy1);
+      buffer_copy_string_buffer(du->key, yymsp[-2].minor.yy43);
       array_replace(vars, du);
     }
-  } else if (NULL != (du = configparser_get_variable(ctx, yymsp[-2].minor.yy1))) {
-    du = configparser_merge_data(du, yymsp[0].minor.yy43);
+  } else if (NULL != (du = configparser_get_variable(ctx, yymsp[-2].minor.yy43))) {
+    du = configparser_merge_data(du, yymsp[0].minor.yy41);
     if (NULL == du) {
       ctx->ok = 0;
     }
     else {
-      buffer_copy_string_buffer(du->key, yymsp[-2].minor.yy1);
+      buffer_copy_string_buffer(du->key, yymsp[-2].minor.yy43);
       array_insert_unique(ctx->current->value, du);
     }
   } else {
     fprintf(stderr, "Undefined config variable in conditional %d %s: %s\n", 
             ctx->current->context_ndx,
-            ctx->current->key->ptr, yymsp[-2].minor.yy1->ptr);
+            ctx->current->key->ptr, yymsp[-2].minor.yy43->ptr);
     ctx->ok = 0;
   }
-  buffer_free(yymsp[-2].minor.yy1);
-  yymsp[-2].minor.yy1 = NULL;
-  yymsp[0].minor.yy43->free(yymsp[0].minor.yy43);
-  yymsp[0].minor.yy43 = NULL;
+  buffer_free(yymsp[-2].minor.yy43);
+  yymsp[-2].minor.yy43 = NULL;
+  yymsp[0].minor.yy41->free(yymsp[0].minor.yy41);
+  yymsp[0].minor.yy41 = NULL;
 }
-#line 890 "configparser.c"
+#line 906 "configparser.c"
   yy_destructor(3,&yymsp[-1].minor);
         break;
-      case 10:
-#line 213 "./configparser.y"
+      case 11:
+#line 214 "./configparser.y"
 {
   if (strchr(yymsp[0].minor.yy0->ptr, '.') == NULL) {
-    yygotominor.yy1 = buffer_init_string("var.");
-    buffer_append_string_buffer(yygotominor.yy1, yymsp[0].minor.yy0);
+    yygotominor.yy43 = buffer_init_string("var.");
+    buffer_append_string_buffer(yygotominor.yy43, yymsp[0].minor.yy0);
     buffer_free(yymsp[0].minor.yy0);
     yymsp[0].minor.yy0 = NULL;
   } else {
-    yygotominor.yy1 = yymsp[0].minor.yy0;
+    yygotominor.yy43 = yymsp[0].minor.yy0;
     yymsp[0].minor.yy0 = NULL;
   }
 }
-#line 906 "configparser.c"
-        break;
-      case 11:
-#line 225 "./configparser.y"
-{
-  yygotominor.yy43 = configparser_merge_data(yymsp[-2].minor.yy43, yymsp[0].minor.yy43);
-  if (NULL == yygotominor.yy43) {
-    ctx->ok = 0;
-  }
-  yymsp[-2].minor.yy43 = NULL;
-  yymsp[0].minor.yy43->free(yymsp[0].minor.yy43);
-  yymsp[0].minor.yy43 = NULL;
-}
-#line 919 "configparser.c"
-  yy_destructor(5,&yymsp[-1].minor);
+#line 922 "configparser.c"
         break;
       case 12:
-#line 235 "./configparser.y"
+#line 226 "./configparser.y"
 {
-  yygotominor.yy43 = yymsp[0].minor.yy43;
-  yymsp[0].minor.yy43 = NULL;
+  yygotominor.yy41 = configparser_merge_data(yymsp[-2].minor.yy41, yymsp[0].minor.yy41);
+  if (NULL == yygotominor.yy41) {
+    ctx->ok = 0;
+  }
+  yymsp[-2].minor.yy41 = NULL;
+  yymsp[0].minor.yy41->free(yymsp[0].minor.yy41);
+  yymsp[0].minor.yy41 = NULL;
 }
-#line 928 "configparser.c"
+#line 935 "configparser.c"
+  yy_destructor(5,&yymsp[-1].minor);
         break;
       case 13:
-#line 240 "./configparser.y"
+#line 236 "./configparser.y"
 {
-  yygotominor.yy43 = configparser_get_variable(ctx, yymsp[0].minor.yy1);
-  if (!yygotominor.yy43) {
-    /* make a dummy so it won't crash */
-    yygotominor.yy43 = (data_unset *)data_string_init();
-  }
-  buffer_free(yymsp[0].minor.yy1);
-  yymsp[0].minor.yy1 = NULL;
+  yygotominor.yy41 = yymsp[0].minor.yy41;
+  yymsp[0].minor.yy41 = NULL;
 }
-#line 941 "configparser.c"
+#line 944 "configparser.c"
         break;
       case 14:
-#line 250 "./configparser.y"
+#line 241 "./configparser.y"
 {
-  yygotominor.yy43 = (data_unset *)data_string_init();
-  buffer_copy_string_buffer(((data_string *)(yygotominor.yy43))->value, yymsp[0].minor.yy0);
-  buffer_free(yymsp[0].minor.yy0);
-  yymsp[0].minor.yy0 = NULL;
+  yygotominor.yy41 = configparser_get_variable(ctx, yymsp[0].minor.yy43);
+  if (!yygotominor.yy41) {
+    /* make a dummy so it won't crash */
+    yygotominor.yy41 = (data_unset *)data_string_init();
+  }
+  buffer_free(yymsp[0].minor.yy43);
+  yymsp[0].minor.yy43 = NULL;
 }
-#line 951 "configparser.c"
+#line 957 "configparser.c"
         break;
       case 15:
-#line 257 "./configparser.y"
+#line 251 "./configparser.y"
 {
-  yygotominor.yy43 = (data_unset *)data_integer_init();
-  ((data_integer *)(yygotominor.yy43))->value = strtol(yymsp[0].minor.yy0->ptr, NULL, 10);
+  yygotominor.yy41 = (data_unset *)data_string_init();
+  buffer_copy_string_buffer(((data_string *)(yygotominor.yy41))->value, yymsp[0].minor.yy0);
   buffer_free(yymsp[0].minor.yy0);
   yymsp[0].minor.yy0 = NULL;
 }
-#line 961 "configparser.c"
+#line 967 "configparser.c"
         break;
       case 16:
-#line 263 "./configparser.y"
+#line 258 "./configparser.y"
 {
-  yygotominor.yy43 = (data_unset *)data_array_init();
-  array_free(((data_array *)(yygotominor.yy43))->value);
-  ((data_array *)(yygotominor.yy43))->value = yymsp[0].minor.yy78;
-  yymsp[0].minor.yy78 = NULL;
+  yygotominor.yy41 = (data_unset *)data_integer_init();
+  ((data_integer *)(yygotominor.yy41))->value = strtol(yymsp[0].minor.yy0->ptr, NULL, 10);
+  buffer_free(yymsp[0].minor.yy0);
+  yymsp[0].minor.yy0 = NULL;
 }
-#line 971 "configparser.c"
+#line 977 "configparser.c"
         break;
       case 17:
-#line 269 "./configparser.y"
+#line 264 "./configparser.y"
 {
-  yygotominor.yy78 = yymsp[-1].minor.yy78;
-  yymsp[-1].minor.yy78 = NULL;
+  yygotominor.yy41 = (data_unset *)data_array_init();
+  array_free(((data_array *)(yygotominor.yy41))->value);
+  ((data_array *)(yygotominor.yy41))->value = yymsp[0].minor.yy40;
+  yymsp[0].minor.yy40 = NULL;
 }
-#line 979 "configparser.c"
+#line 987 "configparser.c"
+        break;
+      case 18:
+#line 270 "./configparser.y"
+{
+  yygotominor.yy40 = yymsp[-1].minor.yy40;
+  yymsp[-1].minor.yy40 = NULL;
+}
+#line 995 "configparser.c"
   yy_destructor(8,&yymsp[-2].minor);
   yy_destructor(9,&yymsp[0].minor);
         break;
-      case 18:
-#line 274 "./configparser.y"
+      case 19:
+#line 275 "./configparser.y"
 {
-  if (buffer_is_empty(yymsp[0].minor.yy43->key) ||
-      NULL == array_get_element(yymsp[-2].minor.yy78, yymsp[0].minor.yy43->key->ptr)) {
-    array_insert_unique(yymsp[-2].minor.yy78, yymsp[0].minor.yy43);
-    yymsp[0].minor.yy43 = NULL;
+  if (buffer_is_empty(yymsp[0].minor.yy41->key) ||
+      NULL == array_get_element(yymsp[-2].minor.yy40, yymsp[0].minor.yy41->key->ptr)) {
+    array_insert_unique(yymsp[-2].minor.yy40, yymsp[0].minor.yy41);
+    yymsp[0].minor.yy41 = NULL;
   } else {
     fprintf(stderr, "Duplicate array-key: %s\n", 
-            yymsp[0].minor.yy43->key->ptr);
+            yymsp[0].minor.yy41->key->ptr);
     ctx->ok = 0;
-    yymsp[0].minor.yy43->free(yymsp[0].minor.yy43);
-    yymsp[0].minor.yy43 = NULL;
+    yymsp[0].minor.yy41->free(yymsp[0].minor.yy41);
+    yymsp[0].minor.yy41 = NULL;
   }
   
-  yygotominor.yy78 = yymsp[-2].minor.yy78;
-  yymsp[-2].minor.yy78 = NULL;
+  yygotominor.yy40 = yymsp[-2].minor.yy40;
+  yymsp[-2].minor.yy40 = NULL;
 }
-#line 1001 "configparser.c"
+#line 1017 "configparser.c"
   yy_destructor(10,&yymsp[-1].minor);
         break;
-      case 19:
-#line 291 "./configparser.y"
+      case 20:
+#line 292 "./configparser.y"
 {
-  yygotominor.yy78 = yymsp[-1].minor.yy78;
-  yymsp[-1].minor.yy78 = NULL;
+  yygotominor.yy40 = yymsp[-1].minor.yy40;
+  yymsp[-1].minor.yy40 = NULL;
 }
-#line 1010 "configparser.c"
+#line 1026 "configparser.c"
   yy_destructor(10,&yymsp[0].minor);
         break;
-      case 20:
-#line 296 "./configparser.y"
-{
-  yygotominor.yy78 = array_init();
-  array_insert_unique(yygotominor.yy78, yymsp[0].minor.yy43);
-  yymsp[0].minor.yy43 = NULL;
-}
-#line 1020 "configparser.c"
-        break;
       case 21:
-#line 302 "./configparser.y"
+#line 297 "./configparser.y"
 {
-  yygotominor.yy43 = yymsp[0].minor.yy43;
-  yymsp[0].minor.yy43 = NULL;
+  yygotominor.yy40 = array_init();
+  array_insert_unique(yygotominor.yy40, yymsp[0].minor.yy41);
+  yymsp[0].minor.yy41 = NULL;
 }
-#line 1028 "configparser.c"
+#line 1036 "configparser.c"
         break;
       case 22:
-#line 306 "./configparser.y"
+#line 303 "./configparser.y"
 {
-  buffer_copy_string_buffer(yymsp[0].minor.yy43->key, yymsp[-2].minor.yy1);
-  buffer_free(yymsp[-2].minor.yy1);
-  yymsp[-2].minor.yy1 = NULL;
-  
-  yygotominor.yy43 = yymsp[0].minor.yy43;
-  yymsp[0].minor.yy43 = NULL;
+  yygotominor.yy41 = yymsp[0].minor.yy41;
+  yymsp[0].minor.yy41 = NULL;
 }
-#line 1040 "configparser.c"
-  yy_destructor(11,&yymsp[-1].minor);
+#line 1044 "configparser.c"
         break;
       case 23:
-  yy_destructor(1,&yymsp[0].minor);
+#line 307 "./configparser.y"
+{
+  buffer_copy_string_buffer(yymsp[0].minor.yy41->key, yymsp[-2].minor.yy43);
+  buffer_free(yymsp[-2].minor.yy43);
+  yymsp[-2].minor.yy43 = NULL;
+  
+  yygotominor.yy41 = yymsp[0].minor.yy41;
+  yymsp[0].minor.yy41 = NULL;
+}
+#line 1056 "configparser.c"
+  yy_destructor(11,&yymsp[-1].minor);
         break;
       case 24:
+  yy_destructor(1,&yymsp[0].minor);
         break;
       case 25:
-#line 318 "./configparser.y"
-{
-  assert(yymsp[-3].minor.yy74->context_ndx < yymsp[0].minor.yy74->context_ndx);
-  yymsp[0].minor.yy74->prev = yymsp[-3].minor.yy74;
-  yymsp[-3].minor.yy74->next = yymsp[0].minor.yy74;
-  yygotominor.yy74 = yymsp[0].minor.yy74;
-  yymsp[-3].minor.yy74 = NULL;
-  yymsp[0].minor.yy74 = NULL;
-}
-#line 1058 "configparser.c"
-        /* No destructor defined for eols */
-  yy_destructor(12,&yymsp[-1].minor);
         break;
       case 26:
-#line 327 "./configparser.y"
+#line 319 "./configparser.y"
 {
-  yygotominor.yy74 = yymsp[0].minor.yy74;
-  yymsp[0].minor.yy74 = NULL;
+  data_config *dc;
+  dc = (data_config *)array_get_element(ctx->srv->config_context, "global");
+  assert(dc);
+  configparser_push(ctx, dc, 0);
 }
-#line 1068 "configparser.c"
+#line 1072 "configparser.c"
+  yy_destructor(12,&yymsp[0].minor);
         break;
       case 27:
-#line 332 "./configparser.y"
+#line 326 "./configparser.y"
 {
   data_config *cur;
   
@@ -1077,26 +1082,66 @@ static void yy_reduce(
 
   assert(cur && ctx->current);
 
-  yygotominor.yy74 = cur;
+  yygotominor.yy0 = cur;
 }
-#line 1082 "configparser.c"
-        /* No destructor defined for context */
+#line 1087 "configparser.c"
+        /* No destructor defined for globalstart */
   yy_destructor(13,&yymsp[-2].minor);
         /* No destructor defined for metalines */
   yy_destructor(14,&yymsp[0].minor);
         break;
       case 28:
-#line 343 "./configparser.y"
+#line 337 "./configparser.y"
+{
+  assert(yymsp[-3].minor.yy78->context_ndx < yymsp[0].minor.yy78->context_ndx);
+  yymsp[0].minor.yy78->prev = yymsp[-3].minor.yy78;
+  yymsp[-3].minor.yy78->next = yymsp[0].minor.yy78;
+  yygotominor.yy78 = yymsp[0].minor.yy78;
+  yymsp[-3].minor.yy78 = NULL;
+  yymsp[0].minor.yy78 = NULL;
+}
+#line 1103 "configparser.c"
+        /* No destructor defined for eols */
+  yy_destructor(15,&yymsp[-1].minor);
+        break;
+      case 29:
+#line 346 "./configparser.y"
+{
+  yygotominor.yy78 = yymsp[0].minor.yy78;
+  yymsp[0].minor.yy78 = NULL;
+}
+#line 1113 "configparser.c"
+        break;
+      case 30:
+#line 351 "./configparser.y"
+{
+  data_config *cur;
+  
+  cur = ctx->current;
+  configparser_pop(ctx);
+
+  assert(cur && ctx->current);
+
+  yygotominor.yy78 = cur;
+}
+#line 1127 "configparser.c"
+        /* No destructor defined for context */
+  yy_destructor(13,&yymsp[-2].minor);
+        /* No destructor defined for metalines */
+  yy_destructor(14,&yymsp[0].minor);
+        break;
+      case 31:
+#line 362 "./configparser.y"
 {
   data_config *dc;
   buffer *b, *rvalue, *op;
 
-  if (ctx->ok && yymsp[0].minor.yy43->type != TYPE_STRING) {
+  if (ctx->ok && yymsp[0].minor.yy41->type != TYPE_STRING) {
     fprintf(stderr, "rvalue must be string");
     ctx->ok = 0;
   }
 
-  switch(yymsp[-1].minor.yy29) {
+  switch(yymsp[-1].minor.yy27) {
   case CONFIG_COND_NE:
     op = buffer_init_string("!=");
     break;
@@ -1118,9 +1163,9 @@ static void yy_reduce(
   buffer_copy_string_buffer(b, ctx->current->key);
   buffer_append_string(b, "/");
   buffer_append_string_buffer(b, yymsp[-5].minor.yy0);
-  buffer_append_string_buffer(b, yymsp[-3].minor.yy1);
+  buffer_append_string_buffer(b, yymsp[-3].minor.yy43);
   buffer_append_string_buffer(b, op);
-  rvalue = ((data_string*)yymsp[0].minor.yy43)->value;
+  rvalue = ((data_string*)yymsp[0].minor.yy41)->value;
   buffer_append_string_buffer(b, rvalue);
   
   if (NULL != (dc = (data_config *)array_get_element(ctx->all_configs, b->ptr))) {
@@ -1148,9 +1193,9 @@ static void yy_reduce(
     buffer_copy_string_buffer(dc->op, op);
     buffer_copy_string_buffer(dc->comp_key, yymsp[-5].minor.yy0);
     buffer_append_string_len(dc->comp_key, CONST_STR_LEN("[\""));
-    buffer_append_string_buffer(dc->comp_key, yymsp[-3].minor.yy1);
+    buffer_append_string_buffer(dc->comp_key, yymsp[-3].minor.yy43);
     buffer_append_string_len(dc->comp_key, CONST_STR_LEN("\"]"));
-    dc->cond = yymsp[-1].minor.yy29;
+    dc->cond = yymsp[-1].minor.yy27;
     
     for (i = 0; comps[i].comp_key; i ++) {
       if (buffer_is_equal_string(
@@ -1164,7 +1209,7 @@ static void yy_reduce(
       ctx->ok = 0;
     }
 
-    switch(yymsp[-1].minor.yy29) {
+    switch(yymsp[-1].minor.yy27) {
     case CONFIG_COND_NE:
     case CONFIG_COND_EQ:
       dc->string = buffer_init_buffer(rvalue);
@@ -1194,9 +1239,9 @@ static void yy_reduce(
         dc->string = buffer_init_buffer(rvalue);
       }
 #else
-      fprintf(stderr, "regex conditionals are not allowed as pcre-support" \
-                      "is missing: $%s[%s]\n", 
-                      yymsp[-5].minor.yy0->ptr, yymsp[-3].minor.yy1->ptr);
+      fprintf(stderr, "can't handle '$%s[%s] =~ ...' as you compiled without pcre support. \n"
+		      "(perhaps just a missing pcre-devel package ?) \n", 
+                      yymsp[-5].minor.yy0->ptr, yymsp[-3].minor.yy43->ptr);
       ctx->ok = 0;
 #endif
       break;
@@ -1204,7 +1249,7 @@ static void yy_reduce(
 
     default:
       fprintf(stderr, "unknown condition for $%s[%s]\n", 
-                      yymsp[-5].minor.yy0->ptr, yymsp[-3].minor.yy1->ptr);
+                      yymsp[-5].minor.yy0->ptr, yymsp[-3].minor.yy43->ptr);
       ctx->ok = 0;
       break;
     }
@@ -1216,96 +1261,96 @@ static void yy_reduce(
   buffer_free(op);
   buffer_free(yymsp[-5].minor.yy0);
   yymsp[-5].minor.yy0 = NULL;
-  buffer_free(yymsp[-3].minor.yy1);
-  yymsp[-3].minor.yy1 = NULL;
-  yymsp[0].minor.yy43->free(yymsp[0].minor.yy43);
-  yymsp[0].minor.yy43 = NULL;
+  buffer_free(yymsp[-3].minor.yy43);
+  yymsp[-3].minor.yy43 = NULL;
+  yymsp[0].minor.yy41->free(yymsp[0].minor.yy41);
+  yymsp[0].minor.yy41 = NULL;
 }
-#line 1224 "configparser.c"
-  yy_destructor(15,&yymsp[-6].minor);
-  yy_destructor(17,&yymsp[-4].minor);
-  yy_destructor(18,&yymsp[-2].minor);
-        break;
-      case 29:
-#line 477 "./configparser.y"
-{
-  yygotominor.yy29 = CONFIG_COND_EQ;
-}
-#line 1234 "configparser.c"
-  yy_destructor(19,&yymsp[0].minor);
-        break;
-      case 30:
-#line 480 "./configparser.y"
-{
-  yygotominor.yy29 = CONFIG_COND_MATCH;
-}
-#line 1242 "configparser.c"
-  yy_destructor(20,&yymsp[0].minor);
-        break;
-      case 31:
-#line 483 "./configparser.y"
-{
-  yygotominor.yy29 = CONFIG_COND_NE;
-}
-#line 1250 "configparser.c"
-  yy_destructor(21,&yymsp[0].minor);
+#line 1269 "configparser.c"
+  yy_destructor(16,&yymsp[-6].minor);
+  yy_destructor(18,&yymsp[-4].minor);
+  yy_destructor(19,&yymsp[-2].minor);
         break;
       case 32:
-#line 486 "./configparser.y"
+#line 496 "./configparser.y"
 {
-  yygotominor.yy29 = CONFIG_COND_NOMATCH;
+  yygotominor.yy27 = CONFIG_COND_EQ;
 }
-#line 1258 "configparser.c"
-  yy_destructor(22,&yymsp[0].minor);
+#line 1279 "configparser.c"
+  yy_destructor(20,&yymsp[0].minor);
         break;
       case 33:
-#line 490 "./configparser.y"
+#line 499 "./configparser.y"
 {
-  yygotominor.yy1 = NULL;
+  yygotominor.yy27 = CONFIG_COND_MATCH;
+}
+#line 1287 "configparser.c"
+  yy_destructor(21,&yymsp[0].minor);
+        break;
+      case 34:
+#line 502 "./configparser.y"
+{
+  yygotominor.yy27 = CONFIG_COND_NE;
+}
+#line 1295 "configparser.c"
+  yy_destructor(22,&yymsp[0].minor);
+        break;
+      case 35:
+#line 505 "./configparser.y"
+{
+  yygotominor.yy27 = CONFIG_COND_NOMATCH;
+}
+#line 1303 "configparser.c"
+  yy_destructor(23,&yymsp[0].minor);
+        break;
+      case 36:
+#line 509 "./configparser.y"
+{
+  yygotominor.yy43 = NULL;
   if (ctx->ok) {
-    if (yymsp[0].minor.yy43->type == TYPE_STRING) {
-      yygotominor.yy1 = buffer_init_buffer(((data_string*)yymsp[0].minor.yy43)->value);
-    } else if (yymsp[0].minor.yy43->type == TYPE_INTEGER) {
-      yygotominor.yy1 = buffer_init();
-      buffer_copy_long(yygotominor.yy1, ((data_integer *)yymsp[0].minor.yy43)->value);
+    if (yymsp[0].minor.yy41->type == TYPE_STRING) {
+      yygotominor.yy43 = buffer_init_buffer(((data_string*)yymsp[0].minor.yy41)->value);
+    } else if (yymsp[0].minor.yy41->type == TYPE_INTEGER) {
+      yygotominor.yy43 = buffer_init();
+      buffer_copy_long(yygotominor.yy43, ((data_integer *)yymsp[0].minor.yy41)->value);
     } else {
       fprintf(stderr, "operand must be string");
       ctx->ok = 0;
     }
   }
-  yymsp[0].minor.yy43->free(yymsp[0].minor.yy43);
-  yymsp[0].minor.yy43 = NULL;
+  yymsp[0].minor.yy41->free(yymsp[0].minor.yy41);
+  yymsp[0].minor.yy41 = NULL;
 }
-#line 1279 "configparser.c"
+#line 1324 "configparser.c"
         break;
-      case 34:
-#line 507 "./configparser.y"
+      case 37:
+#line 526 "./configparser.y"
 {
   if (ctx->ok) {
-    if (0 != config_parse_file(ctx->srv, ctx, yymsp[0].minor.yy1->ptr)) {
+    if (0 != config_parse_file(ctx->srv, ctx, yymsp[0].minor.yy43->ptr)) {
       ctx->ok = 0;
     }
-    buffer_free(yymsp[0].minor.yy1);
-    yymsp[0].minor.yy1 = NULL;
+    buffer_free(yymsp[0].minor.yy43);
+    yymsp[0].minor.yy43 = NULL;
   }
 }
-#line 1292 "configparser.c"
-  yy_destructor(23,&yymsp[-1].minor);
-        break;
-      case 35:
-#line 517 "./configparser.y"
-{
-  if (ctx->ok) {
-    if (0 != config_parse_cmd(ctx->srv, ctx, yymsp[0].minor.yy1->ptr)) {
-      ctx->ok = 0;
-    }
-    buffer_free(yymsp[0].minor.yy1);
-    yymsp[0].minor.yy1 = NULL;
-  }
-}
-#line 1306 "configparser.c"
+#line 1337 "configparser.c"
   yy_destructor(24,&yymsp[-1].minor);
         break;
+      case 38:
+#line 536 "./configparser.y"
+{
+  if (ctx->ok) {
+    if (0 != config_parse_cmd(ctx->srv, ctx, yymsp[0].minor.yy43->ptr)) {
+      ctx->ok = 0;
+    }
+    buffer_free(yymsp[0].minor.yy43);
+    yymsp[0].minor.yy43 = NULL;
+  }
+}
+#line 1351 "configparser.c"
+  yy_destructor(25,&yymsp[-1].minor);
+        break;
   };
   yygoto = yyRuleInfo[yyruleno].lhs;
   yysize = yyRuleInfo[yyruleno].nrhs;
@@ -1337,7 +1382,7 @@ static void yy_parse_failed(
 
   ctx->ok = 0;
 
-#line 1340 "configparser.c"
+#line 1385 "configparser.c"
   configparserARG_STORE; /* Suppress warning about unused %extra_argument variable */
 }
 
