@@ -100,8 +100,15 @@ static int fdevent_freebsd_kqueue_poll(fdevents *ev, int timeout_ms) {
 		     &ts);
 
 	if (ret == -1) {
-		fprintf(stderr, "%s.%d: kqueue failed polling: %s\n",
-			__FILE__, __LINE__, strerror(errno));
+		switch(errno) {
+		case EINTR:
+			/* we got interrupted, perhaps just a SIGCHLD of a CGI script */
+			return 0;
+		default:
+			fprintf(stderr, "%s.%d: kqueue failed polling: %s\n",
+				__FILE__, __LINE__, strerror(errno));
+			break;
+		}
 	}
 
 	return ret;
@@ -142,8 +149,6 @@ static int fdevent_freebsd_kqueue_event_next_fdndx(fdevents *ev, int ndx) {
 }
 
 static int fdevent_freebsd_kqueue_reset(fdevents *ev) {
-	close(ev->kq_fd);
-	
 	if (-1 == (ev->kq_fd = kqueue())) {
 		fprintf(stderr, "%s.%d: kqueue failed (%s), try to set server.event-handler = \"poll\" or \"select\"\n",
 			__FILE__, __LINE__, strerror(errno));
@@ -171,14 +176,22 @@ int fdevent_freebsd_kqueue_init(fdevents *ev) {
 	SET(event_get_fd);
 	SET(event_get_revent);
 
+	ev->kq_fd = -1;
+
+	ev->kq_results = calloc(ev->maxfds, sizeof(*ev->kq_results));
+	ev->kq_bevents = bitset_init(ev->maxfds);
+
+	/* check that kqueue works */
+
 	if (-1 == (ev->kq_fd = kqueue())) {
 		fprintf(stderr, "%s.%d: kqueue failed (%s), try to set server.event-handler = \"poll\" or \"select\"\n",
 			__FILE__, __LINE__, strerror(errno));
 		
 		return -1;
 	}
-	ev->kq_results = calloc(ev->maxfds, sizeof(*ev->kq_results));
-	ev->kq_bevents = bitset_init(ev->maxfds);
+
+	close(ev->kq_fd);
+	ev->kq_fd = -1;
 
 	return 0;
 }
