@@ -34,7 +34,6 @@
 #ifdef USE_OPENSSL
 # include <openssl/md5.h>
 #else
-# include "md5_global.h"
 # include "md5.h"
 #endif
 
@@ -49,6 +48,8 @@ static struct pam_conv conv = {
 };
 #endif
 
+handler_t auth_ldap_init(server *srv, mod_auth_plugin_config *s);
+
 static const char base64_pad = '=';
 
 static const short base64_reverse_table[256] = {
@@ -349,19 +350,25 @@ static int http_auth_match_rules(server *srv, mod_auth_plugin_data *p, const cha
 		/* from r to r + r_len is a rule */
 		
 		if (0 == strncmp(r, "valid-user", r_len)) {
-			log_error_write(srv, __FILE__, __LINE__, "s", "valid-user cannot be combined with other require rules");
+			log_error_write(srv, __FILE__, __LINE__, "sb", 
+					"parsing the 'require' section in 'auth.require' failed: valid-user cannot be combined with other require rules",
+					require->value);
 			return -1;
 		}
 		
 		/* search for = in the rules */
 		if (NULL == (eq = strchr(r, '='))) {
-			log_error_write(srv, __FILE__, __LINE__, "s", "= is missing");
+			log_error_write(srv, __FILE__, __LINE__, "sb", 
+					"parsing the 'require' section in 'auth.require' failed: a = is missing", 
+					require->value);
 			return -1;
 		}
 		
 		/* = out of range */
 		if (eq > r + r_len) {
-			log_error_write(srv, __FILE__, __LINE__, "s", "= out of range");
+			log_error_write(srv, __FILE__, __LINE__, "sb", 
+					"parsing the 'require' section in 'auth.require' failed: = out of range",
+					require->value);
 			
 			return -1;
 		}
@@ -480,7 +487,7 @@ static int http_auth_basic_password_compare(server *srv, mod_auth_plugin_data *p
 			salt_len = dollar - password->ptr;
 		}
 
-		if (salt_len - 1 > sizeof(salt)) {
+		if (salt_len > sizeof(salt) - 1) {
 			fprintf(stderr, "%s.%d\n", __FILE__, __LINE__);
 			return -1;
 		}
@@ -577,11 +584,17 @@ static int http_auth_basic_password_compare(server *srv, mod_auth_plugin_data *p
 		
 		
 		/* 2. */
-		if (LDAP_SUCCESS != (ret = ldap_search_s(p->conf.ldap, p->conf.auth_ldap_basedn->ptr, LDAP_SCOPE_SUBTREE, p->ldap_filter->ptr, attrs, 0, &lm))) {
+		if (p->conf.ldap == NULL ||
+		    LDAP_SUCCESS != (ret = ldap_search_s(p->conf.ldap, p->conf.auth_ldap_basedn->ptr, LDAP_SCOPE_SUBTREE, p->ldap_filter->ptr, attrs, 0, &lm))) {
+			if (auth_ldap_init(srv, &p->conf) != HANDLER_GO_ON)
+				return -1;
+			if (LDAP_SUCCESS != (ret = ldap_search_s(p->conf.ldap, p->conf.auth_ldap_basedn->ptr, LDAP_SCOPE_SUBTREE, p->ldap_filter->ptr, attrs, 0, &lm))) {
+
 			log_error_write(srv, __FILE__, __LINE__, "sssb", 
 					"ldap:", ldap_err2string(ret), "filter:", p->ldap_filter);
 			
 			return -1;
+			}
 		}
 		
 		if (NULL == (first = ldap_first_entry(p->conf.ldap, lm))) {
@@ -793,6 +806,10 @@ int http_auth_digest_check(server *srv, connection *con, mod_auth_plugin_data *p
 	
 	/* parse credentials from client */
 	for (c = b->ptr; *c; c++) {
+		/* skip whitespaces */
+		while (*c == ' ' || *c == '\t') c++;
+		if (!c) break;
+
 		for (i = 0; dkv[i].key; i++) {
 			if ((0 == strncmp(c, dkv[i].key, dkv[i].key_len))) {
 				if ((c[dkv[i].key_len] == '"') && 
@@ -834,7 +851,7 @@ int http_auth_digest_check(server *srv, connection *con, mod_auth_plugin_data *p
 	    !realm ||
 	    !nonce ||
 	    !uri ||
-	    (qop && !nc && !cnonce) ||
+	    (qop && (!nc || !cnonce)) ||
 	    !respons ) {
 		/* missing field */
 		
