@@ -27,6 +27,10 @@ static keyvalue http_methods[] = {
 	{ HTTP_METHOD_LABEL, "LABEL" },
 	{ HTTP_METHOD_CHECKOUT, "CHECKOUT" },
 	{ HTTP_METHOD_CHECKIN, "CHECKIN" },
+	{ HTTP_METHOD_MERGE, "MERGE" },
+	{ HTTP_METHOD_LOCK, "LOCK" },
+	{ HTTP_METHOD_UNLOCK, "UNLOCK" },
+	{ HTTP_METHOD_MKACTIVITY, "MKACTIVITY" },
 	{ HTTP_METHOD_UNCHECKOUT, "UNCHECKOUT" },
 	{ HTTP_METHOD_VERSION_CONTROL, "VERSION-CONTROL" },
 	{ HTTP_METHOD_CONNECT, "CONNECT" },
