@@ -27,6 +27,10 @@ typedef enum {
 	HTTP_METHOD_CHECKIN,
 	HTTP_METHOD_VERSION_CONTROL,
 	HTTP_METHOD_UNCHECKOUT,
+	HTTP_METHOD_MKACTIVITY,
+	HTTP_METHOD_MERGE,
+	HTTP_METHOD_LOCK,
+	HTTP_METHOD_UNLOCK,
 	HTTP_METHOD_LABEL,
 	HTTP_METHOD_CONNECT
 } http_method_t;
