@@ -22,6 +22,7 @@ typedef struct {
 #if defined(HAVE_MEMCACHE_H) 
 	struct memcache *mc;
 #endif
+	buffer *power_magnet;
 } plugin_config;
 
 typedef struct {
@@ -32,8 +33,6 @@ typedef struct {
 	
 	buffer *trigger_handler;
 	
-	buffer *session_id;
-	
 	plugin_config **config_storage;
 	
 	plugin_config conf; 
