@@ -13,7 +13,6 @@
 #ifdef USE_OPENSSL
 # include <openssl/md5.h>
 #else
-# include "md5_global.h"
 # include "md5.h"
 #endif
 
@@ -105,7 +104,7 @@ static int c_to_lua_push(lua_State *L, int tbl, const char *key, size_t key_len,
 }
 
 
-int split_query_string(lua_State *L, int tbl, buffer *qrystr) {
+int cache_export_get_params(lua_State *L, int tbl, buffer *qrystr) {
 	size_t is_key = 1;
 	size_t i;
 	char *key = NULL, *val = NULL;
@@ -129,6 +128,9 @@ int split_query_string(lua_State *L, int tbl, buffer *qrystr) {
 		case '\0': /* fin symbol */
 			if (!is_key) {
 				/* we need at least a = since the last & */
+
+				/* terminate the value */
+				qrystr->ptr[i] = '\0';
 				
 				c_to_lua_push(L, tbl, 
 					      key, strlen(key),
@@ -144,6 +146,68 @@ int split_query_string(lua_State *L, int tbl, buffer *qrystr) {
 	
 	return 0;
 }
+#if 0
+int cache_export_cookie_params(server *srv, connection *con, plugin_data *p) {
+	data_unset *d;
+
+	UNUSED(srv);
+	
+	if (NULL != (d = array_get_element(con->request.headers, "Cookie"))) {
+		data_string *ds = (data_string *)d;
+		size_t key = 0, value = 0;
+		size_t is_key = 1, is_sid = 0;
+		size_t i;
+		
+		/* found COOKIE */
+		if (!DATA_IS_STRING(d)) return -1;
+		if (ds->value->used == 0) return -1;
+			
+		if (ds->value->ptr[0] == '\0' ||
+		    ds->value->ptr[0] == '=' ||
+		    ds->value->ptr[0] == ';') return -1;
+		
+		buffer_reset(p->session_id);
+		for (i = 0; i < ds->value->used; i++) {
+			switch(ds->value->ptr[i]) {
+			case '=':
+				if (is_key) {
+					if (0 == strncmp(ds->value->ptr + key, "PHPSESSID", i - key)) {
+						/* found PHP-session-id-key */
+						is_sid = 1;
+					}
+					value = i + 1;
+				
+					is_key = 0;
+				}
+				
+				break;
+			case ';':
+				if (is_sid) {
+					buffer_copy_string_len(p->session_id, ds->value->ptr + value, i - value);
+				}
+				
+				is_sid = 0;
+				key = i + 1;
+				value = 0;
+				is_key = 1;
+				break;
+			case ' ':
+				if (is_key == 1 && key == i) key = i + 1;
+				if (is_key == 0 && value == i) value = i + 1;
+				break;
+			case '\0':
+				if (is_sid) {
+					buffer_copy_string_len(p->session_id, ds->value->ptr + value, i - value);
+				}
+				/* fin */
+				break;
+			}
+		}
+	}
+	
+	return 0;
+}
+#endif
 
 int cache_parse_lua(server *srv, connection *con, plugin_data *p, buffer *fn) {
 	lua_State *L; 
@@ -216,17 +280,17 @@ int cache_parse_lua(server *srv, connection *con, plugin_data *p, buffer *fn) {
 	header_tbl = lua_gettop(L);
 	lua_gettable(L, LUA_GLOBALSINDEX);
 	
-	
 	buffer_copy_string_buffer(b, con->uri.query);
-	split_query_string(L, header_tbl, b);
+	cache_export_get_params(L, header_tbl, b);
 	buffer_reset(b);
-	
+
+	/* 2 default constants */	
 	lua_pushliteral(L, "CACHE_HIT");
-	lua_pushnumber(L, 0);
+	lua_pushboolean(L, 0);
 	lua_settable(L, LUA_GLOBALSINDEX);
 	
 	lua_pushliteral(L, "CACHE_MISS");
-	lua_pushnumber(L, 1);
+	lua_pushboolean(L, 1);
 	lua_settable(L, LUA_GLOBALSINDEX);
 	
 	/* load lua program */
@@ -248,19 +312,19 @@ int cache_parse_lua(server *srv, connection *con, plugin_data *p, buffer *fn) {
 		response_header_overwrite(srv, con, CONST_STR_LEN("Content-Type"), CONST_BUF_LEN(b));
 	}
 	
-	if (!lua_to_c_is_table(L, "output_include")) {
-		log_error_write(srv, __FILE__, __LINE__, "s",
-				"output_include is missing or not a table");
-		ret = -1;
-		
-		goto error;
-	}
-	
 	if (ret == 0) {
 		/* up to now it is a cache-hit, check if all files exist */
 		
 		int curelem;
 		time_t mtime = 0;
+	
+		if (!lua_to_c_is_table(L, "output_include")) {
+			log_error_write(srv, __FILE__, __LINE__, "s",
+				"output_include is missing or not a table");
+			ret = -1;
+		
+			goto error;
+		}
 		
 		lua_pushstring(L, "output_include");
 		
@@ -282,7 +346,7 @@ int cache_parse_lua(server *srv, connection *con, plugin_data *p, buffer *fn) {
 			/* key' is at index -2 and value' at index -1 */
 			
 			if (lua_isstring(L, -1)) {
-				char *s = lua_tostring(L, -1);
+				const char *s = lua_tostring(L, -1);
 
 				/* the file is relative, make it absolute */
 				if (s[0] != '/') {
@@ -377,13 +441,7 @@ int cache_parse_lua(server *srv, connection *con, plugin_data *p, buffer *fn) {
 		}
 	}
 	
-	if (ret == 1 && buffer_is_empty(p->trigger_handler)) {
-		log_error_write(srv, __FILE__, __LINE__, "s",
-				"cache-miss, but not trigger_handler set");
-		ret = -1;
-	}
-	
-	if (ret == 1) {
+	if (ret == 1 && !buffer_is_empty(p->trigger_handler)) {
 		/* cache-miss */
 		buffer_copy_string_buffer(con->uri.path, p->baseurl);
 		buffer_append_string_buffer(con->uri.path, p->trigger_handler);
