@@ -3,6 +3,7 @@
 
 #include <fcntl.h>
 #include <stdlib.h>
+#include <stdio.h>
 #include <string.h>
 #include <unistd.h>
 #include <errno.h>
@@ -251,16 +252,21 @@ static int mod_rrdtool_create_rrd(server *srv, plugin_data *p, plugin_config *s)
 
 #define PATCH(x) \
 	p->conf.x = s->x;
-static int mod_rrd_patch_connection(server *srv, connection *con, plugin_data *p, const char *stage, size_t stage_len) {
+static int mod_rrd_patch_connection(server *srv, connection *con, plugin_data *p) {
 	size_t i, j;
+	plugin_config *s = p->config_storage[0];
+	
+	PATCH(path_rrdtool_bin);
+	PATCH(path_rrd);
+	
+	p->conf.bytes_written_ptr = &(s->bytes_written);
+	p->conf.bytes_read_ptr = &(s->bytes_read);
+	p->conf.requests_ptr = &(s->requests);
 	
 	/* skip the first, the global context */
 	for (i = 1; i < srv->config_context->used; i++) {
 		data_config *dc = (data_config *)srv->config_context->data[i];
-		plugin_config *s = p->config_storage[i];
-		
-		/* not our stage */
-		if (!buffer_is_equal_string(dc->comp_key, stage, stage_len)) continue;
+		s = p->config_storage[i];
 		
 		/* condition didn't match */
 		if (!config_check_cond(srv, con, dc)) continue;
@@ -282,21 +288,6 @@ static int mod_rrd_patch_connection(server *srv, connection *con, plugin_data *p
 	
 	return 0;
 }
-
-static int mod_rrd_setup_connection(server *srv, connection *con, plugin_data *p) {
-	plugin_config *s = p->config_storage[0];
-	UNUSED(srv);
-	UNUSED(con);
-		
-	PATCH(path_rrdtool_bin);
-	PATCH(path_rrd);
-	
-	p->conf.bytes_written_ptr = &(s->bytes_written);
-	p->conf.bytes_read_ptr = &(s->bytes_read);
-	p->conf.requests_ptr = &(s->requests);
-	
-	return 0;
-}
 #undef PATCH
 
 SETDEFAULTS_FUNC(mod_rrd_set_defaults) {
@@ -311,12 +302,12 @@ SETDEFAULTS_FUNC(mod_rrd_set_defaults) {
 	
 	if (!p) return HANDLER_ERROR;
 	
-	p->config_storage = malloc(srv->config_context->used * sizeof(specific_config *));
+	p->config_storage = calloc(1, srv->config_context->used * sizeof(specific_config *));
 	
 	for (i = 0; i < srv->config_context->used; i++) {
 		plugin_config *s;
 		
-		s = malloc(sizeof(plugin_config));
+		s = calloc(1, sizeof(plugin_config));
 		s->path_rrdtool_bin = buffer_init();
 		s->path_rrd = buffer_init();
 		s->requests = 0;
@@ -431,14 +422,8 @@ TRIGGER_FUNC(mod_rrd_trigger) {
 
 REQUESTDONE_FUNC(mod_rrd_account) {
 	plugin_data *p = p_d;
-	size_t i;
 	
-	mod_rrd_setup_connection(srv, con, p);
-	for (i = 0; i < srv->config_patches->used; i++) {
-		buffer *patch = srv->config_patches->ptr[i];
-		
-		mod_rrd_patch_connection(srv, con, p, CONST_BUF_LEN(patch));
-	}
+	mod_rrd_patch_connection(srv, con, p);
 	
 	*(p->conf.requests_ptr)      += 1;
 	*(p->conf.bytes_written_ptr) += con->bytes_written;
