@@ -252,7 +252,7 @@ int network_server_init(server *srv, buffer *host_token, specific_config *s) {
 		addr_len = SUN_LEN(&srv_socket->addr.un);
 #else
 		/* stevens says: */
-		addr_len = strlen(host) + sizeof(srv_socket->addr.un.sun_family);
+		addr_len = strlen(host) + 1 + sizeof(srv_socket->addr.un.sun_family);
 #endif
 
 		/* check if the socket exists and try to connect to it. */
@@ -540,6 +540,7 @@ int network_init(server *srv) {
 	for (i = 1; i < srv->config_context->used; i++) {
 		data_config *dc = (data_config *)srv->config_context->data[i];
 		specific_config *s = srv->config_storage[i];
+		size_t j;
 		
 		/* not our stage */
 		if (COMP_SERVER_SOCKET != dc->comp) continue;
@@ -549,13 +550,20 @@ int network_init(server *srv) {
 			
 			return -1;
 		}
+
+		/* check if we already know this socket,
+		 * if yes, don't init it */
+		for (j = 0; j < srv->srv_sockets.used; j++) {
+			if (buffer_is_equal(srv->srv_sockets.ptr[j]->srv_token, dc->string)) {
+				break;
+			}
+		}
 		
-		if (0 != network_server_init(srv, dc->string, s)) {
-			return -1;
+		if (j == srv->srv_sockets.used) {
+			if (0 != network_server_init(srv, dc->string, s)) return -1;
 		}
 	}
 	
-	
 	return 0;
 }
 
