@@ -49,6 +49,15 @@ int network_write_chunkqueue_openssl(server *srv, connection *con, SSL *ssl, chu
 #define LOCAL_SEND_BUFSIZE (64 * 1024)
 	static char *local_send_buffer = NULL;
 
+	/* the remote side closed the connection before without shutdown request
+	 * - IE 
+	 * - wget
+	 * if keep-alive is disabled */
+
+	if (con->keep_alive == 0) {
+		SSL_set_shutdown(ssl, SSL_RECEIVED_SHUTDOWN);
+	}
+
 	for(c = cq->first; c; c = c->next) {
 		int chunk_finished = 0;
 		
@@ -85,9 +94,11 @@ int network_write_chunkqueue_openssl(server *srv, connection *con, SSL *ssl, chu
 				case SSL_ERROR_SYSCALL:
 					/* perhaps we have error waiting in our error-queue */
 					if (0 != (err = ERR_get_error())) {
-						log_error_write(srv, __FILE__, __LINE__, "sdds", "SSL:", 
-								ssl_r, r,
-								ERR_error_string(err, NULL));
+						do {
+							log_error_write(srv, __FILE__, __LINE__, "sdds", "SSL:", 
+									ssl_r, r,
+									ERR_error_string(err, NULL));
+						} while((err = ERR_get_error()));
 					} else if (r == -1) {
 						/* no, but we have errno */
 						switch(errno) {
@@ -112,11 +123,13 @@ int network_write_chunkqueue_openssl(server *srv, connection *con, SSL *ssl, chu
 					
 					if (r == 0) return -2;
 					
-					/* fall thourgh */
+					/* fall through */
 				default:
-					log_error_write(srv, __FILE__, __LINE__, "sdds", "SSL:", 
-							ssl_r, r,
-							ERR_error_string(ERR_get_error(), NULL));
+					while((err = ERR_get_error())) {
+						log_error_write(srv, __FILE__, __LINE__, "sdds", "SSL:", 
+								ssl_r, r,
+								ERR_error_string(err, NULL));
+					}
 					
 					return  -1;
 				}
@@ -134,8 +147,6 @@ int network_write_chunkqueue_openssl(server *srv, connection *con, SSL *ssl, chu
 		case FILE_CHUNK: {
 			char *s;
 			ssize_t r;
-			off_t offset;
-			size_t toSend;
 			stat_cache_entry *sce = NULL;
 			int ifd;
 			int write_wait = 0;
@@ -152,14 +163,13 @@ int network_write_chunkqueue_openssl(server *srv, connection *con, SSL *ssl, chu
 			}
 
 			do {
-			
-				offset = c->file.offset + c->offset;
-				toSend = c->file.length - c->offset;
+				off_t offset = c->file.start + c->offset;
+				off_t toSend = c->file.length - c->offset; 
 
 				if (toSend > LOCAL_SEND_BUFSIZE) toSend = LOCAL_SEND_BUFSIZE;
 			
 				if (-1 == (ifd = open(c->file.name->ptr, O_RDONLY))) {
-					log_error_write(srv, __FILE__, __LINE__, "ss", "open failed: ", strerror(errno));
+					log_error_write(srv, __FILE__, __LINE__, "ss", "open failed:", strerror(errno));
 				
 					return -1;
 				}
@@ -167,7 +177,8 @@ int network_write_chunkqueue_openssl(server *srv, connection *con, SSL *ssl, chu
 
 				lseek(ifd, offset, SEEK_SET);
 				if (-1 == (toSend = read(ifd, local_send_buffer, toSend))) {
-					log_error_write(srv, __FILE__, __LINE__, "ss", "read failed: ", strerror(errno));
+					close(ifd);
+					log_error_write(srv, __FILE__, __LINE__, "ss", "read failed:", strerror(errno));
 					return -1;
 				}
 
@@ -176,19 +187,36 @@ int network_write_chunkqueue_openssl(server *srv, connection *con, SSL *ssl, chu
 				close(ifd);
 			
 				if ((r = SSL_write(ssl, s, toSend)) <= 0) {
+					unsigned long err;
+
 					switch ((ssl_r = SSL_get_error(ssl, r))) {
 					case SSL_ERROR_WANT_WRITE:
 						write_wait = 1;
 						break;
 					case SSL_ERROR_SYSCALL:
-						switch(errno) {
-						case EPIPE:
-							return -2;
-						default:
-							log_error_write(srv, __FILE__, __LINE__, "sddds", "SSL:", 
+						/* perhaps we have error waiting in our error-queue */
+						if (0 != (err = ERR_get_error())) {
+							do {
+								log_error_write(srv, __FILE__, __LINE__, "sdds", "SSL:", 
+										ssl_r, r,
+										ERR_error_string(err, NULL));
+							} while((err = ERR_get_error()));
+						} else if (r == -1) {
+							/* no, but we have errno */
+							switch(errno) {
+							case EPIPE:
+								return -2;
+							default:
+								log_error_write(srv, __FILE__, __LINE__, "sddds", "SSL:", 
+										ssl_r, r, errno,
+										strerror(errno));
+								break;
+							}
+						} else {
+							/* neither error-queue nor errno ? */
+							log_error_write(srv, __FILE__, __LINE__, "sddds", "SSL (error):", 
 									ssl_r, r, errno,
 									strerror(errno));
-							break;
 						}
 					
 						return  -1;
@@ -199,9 +227,11 @@ int network_write_chunkqueue_openssl(server *srv, connection *con, SSL *ssl, chu
 					
 						/* fall thourgh */
 					default:
-						log_error_write(srv, __FILE__, __LINE__, "sdds", "SSL:", 
-								ssl_r, r, 
-								ERR_error_string(ERR_get_error(), NULL));
+						while((err = ERR_get_error())) {
+							log_error_write(srv, __FILE__, __LINE__, "sdds", "SSL:", 
+									ssl_r, r,
+									ERR_error_string(err, NULL));
+						}
 					
 						return -1;
 					}
@@ -230,9 +260,8 @@ int network_write_chunkqueue_openssl(server *srv, connection *con, SSL *ssl, chu
 		}
 			
 		chunks_written++;
-		
 	}
-	
+
 	return chunks_written;
 }
 #endif
