@@ -1,13 +1,13 @@
 #!/bin/sh
 
-tmpdir=/tmp/lighttpd
-
 if test x$srcdir = x; then
 	srcdir=.
 fi
 
-# create test-framework
-# rm -rf $tmpdir
+tmpdir=$top_builddir/tests/tmp/
+
+# remove test-framework
+rm -rf $tmpdir
 
 printf "%-40s" "cleaning up"
 
